@@ -4,18 +4,20 @@
 # See top-level LICENSE file for more information
 
 import datetime
+from itertools import islice
+import logging
 import re
 import tempfile
 from unittest.mock import patch
-import logging
 
 from click.testing import CliRunner
 import pytest
 
-from swh.storage import get_storage
+from swh.core.api.classes import stream_results
+from swh.model.model import Origin
 from swh.scheduler.cli import cli
 from swh.scheduler.utils import create_task_dict
-
+from swh.storage import get_storage
 
 CLI_CONFIG = """
 scheduler:
@@ -588,7 +590,7 @@ Task 1
 
 
 def _fill_storage_with_origins(storage, nb_origins):
-    origins = [{"url": "http://example.com/{}".format(i),} for i in range(nb_origins)]
+    origins = [Origin(url=f"http://example.com/{i}") for i in range(nb_origins)]
     storage.origin_add(origins)
     return origins
 
@@ -597,11 +599,7 @@ def _fill_storage_with_origins(storage, nb_origins):
 def storage():
     """An instance of in-memory storage that gets injected
     into the CLI functions."""
-    storage_config = {
-        "cls": "pipeline",
-        "steps": [{"cls": "validate"}, {"cls": "memory"},],
-    }
-    storage = get_storage(**storage_config)
+    storage = get_storage(cls="memory")
     with patch("swh.storage.get_storage") as get_storage_mock:
         get_storage_mock.return_value = storage
         yield storage
@@ -646,7 +644,7 @@ def _assert_origin_tasks_contraints(tasks, max_tasks, max_task_size, expected_or
         expected_origins
     )
     assert set.union(*(set(task["arguments"]["args"][0]) for task in tasks)) == {
-        origin["url"] for origin in expected_origins
+        origin.url for origin in expected_origins
     }
 
 
@@ -710,3 +708,88 @@ Done.
         task["arguments"]["kwargs"] == {"key1": "value1", "key2": "value2"}
         for task in tasks
     )
+
+
+def test_task_schedule_origins_with_limit(swh_scheduler, storage):
+    """Tests support of extra keyword-arguments."""
+    _fill_storage_with_origins(storage, 50)
+    limit = 20
+    expected_origins = list(islice(stream_results(storage.origin_list), limit))
+    nb_origins = len(expected_origins)
+
+    assert nb_origins == limit
+    max_task_size = 5
+    nb_tasks, remainder = divmod(nb_origins, max_task_size)
+    assert remainder == 0  # made the numbers go round
+
+    result = invoke(
+        swh_scheduler,
+        False,
+        [
+            "task",
+            "schedule_origins",
+            "swh-test-ping",
+            "--batch-size",
+            max_task_size,
+            "--limit",
+            limit,
+        ],
+    )
+
+    # Check the output
+    expected = rf"""
+Scheduled {nb_tasks} tasks \({nb_origins} origins\).
+Done.
+""".lstrip()
+    assert result.exit_code == 0, result.output
+    assert re.fullmatch(expected, result.output, re.MULTILINE), repr(result.output)
+
+    tasks = swh_scheduler.search_tasks()
+    _assert_origin_tasks_contraints(tasks, max_task_size, nb_origins, expected_origins)
+
+
+def test_task_schedule_origins_with_page_token(swh_scheduler, storage):
+    """Tests support of extra keyword-arguments."""
+    nb_total_origins = 50
+    origins = _fill_storage_with_origins(storage, nb_total_origins)
+
+    # prepare page_token and origins result expectancy
+    page_result = storage.origin_list(limit=10)
+    assert len(page_result.results) == 10
+    page_token = page_result.next_page_token
+    assert page_token is not None
+
+    # remove the first 10 origins listed as we won't see those in tasks
+    expected_origins = [o for o in origins if o not in page_result.results]
+    nb_origins = len(expected_origins)
+    assert nb_origins == nb_total_origins - len(page_result.results)
+
+    max_task_size = 10
+    nb_tasks, remainder = divmod(nb_origins, max_task_size)
+    assert remainder == 0
+
+    result = invoke(
+        swh_scheduler,
+        False,
+        [
+            "task",
+            "schedule_origins",
+            "swh-test-ping",
+            "--batch-size",
+            max_task_size,
+            "--page-token",
+            page_token,
+        ],
+    )
+
+    # Check the output
+    expected = rf"""
+Scheduled {nb_tasks} tasks \({nb_origins} origins\).
+Done.
+""".lstrip()
+    assert result.exit_code == 0, result.output
+    assert re.fullmatch(expected, result.output, re.MULTILINE), repr(result.output)
+
+    # Check tasks
+    tasks = swh_scheduler.search_tasks()
+    _assert_origin_tasks_contraints(tasks, max_task_size, nb_origins, expected_origins)
