@@ -48,7 +48,7 @@ def local_sched_config(swh_scheduler_config):
     """Expose the local scheduler configuration
 
     """
-    return {"scheduler": {"cls": "local", "args": swh_scheduler_config}}
+    return {"scheduler": {"cls": "local", **swh_scheduler_config}}
 
 
 @pytest.fixture
